#coding: utf-8

from m3.db import BaseEnumerate

# Standard Library
from kinder.core.declaration_status.models import DSS


class ConcentratorDelegateDocType(BaseEnumerate):
    """
    Типы документов представителя в концентраторе
    """

    USSR_PASSPORT = 1
    ABROAD_USSR_PASSPORT = 2
    IDENTITY_CARD = 4
    CERTIFICATE_OF_RELEASE = 5
    MINMORFLOT_PASSPORT = 6
    MILITARY_ID = 7
    DIPLOMATIC_RF_PASSPORT = 9
    ABROAD_PASSPORT = 10
    CERTIFICATE_OF_REGISTRATION = 11
    RESIDENCE_PERMIT = 12
    REFUGEE_CERTIFICATE = 13
    TEMPORARY_IDENTITY_CARD = 14
    RF_PASSPORT = 21
    ABROAD_RF_PASSPORT = 22
    MARINE_PASSPORT = 26
    MILITARY_ID_RESERVE_OFFICER = 27

    values = {
        USSR_PASSPORT: u'Паспорт гражданина СССР',
        ABROAD_USSR_PASSPORT: u'Загранпаспорт гражданина СССР',
        IDENTITY_CARD: u'Удостоверение личности',
        CERTIFICATE_OF_RELEASE: u'Справка об освобождение',
        MINMORFLOT_PASSPORT: u'Паспорт Минморфлота',
        MILITARY_ID: u'Военный билет',
        DIPLOMATIC_RF_PASSPORT: u'Дипломатический паспорт гражданина РФ',
        ABROAD_PASSPORT: u'Иностранный паспорт',
        CERTIFICATE_OF_REGISTRATION: u'Свидетельство о регистрации '
                                     u'ходатайства иммигранта о '
                                     u'признании его беженцом',
        RESIDENCE_PERMIT: u'Вид на жительство',
        REFUGEE_CERTIFICATE: u'Удостоверение беженца',
        TEMPORARY_IDENTITY_CARD: u'Временное удостоверение '
                                 u'личности гражданина РФ',
        RF_PASSPORT: u'Паспорт гражданина РФ',
        ABROAD_RF_PASSPORT: u'Загранпаспорт гражданина РФ',
        MARINE_PASSPORT: u'Паспорт моряка',
        MILITARY_ID_RESERVE_OFFICER: u'Военный билет офицера запаса'
    }


class ConcentratorChildrenDocType(BaseEnumerate):
    """
    Типы документов ребенка в концентраторе
    """

    BIRTH_CERTIFICATE = 3
    ABROAD_BIRTH_CERTIFICATE = 23

    values = {
        BIRTH_CERTIFICATE: u'Свидетельство о рождении',
        ABROAD_BIRTH_CERTIFICATE: u'Свидетельство о рождении '
                                  u'выданное уполномоченным '
                                  u'органом иностранного государства'
    }


class ResetDeclarationResponse(object):

    SUCCESS = u'Успех'
    ALREADY_ENROLLED = u'Ребенок уже зачислен'
    ALREADY_DIRECTED = u'Ребенок уже направлен в ДОО'
    SERVICE_IS_NOT_AVAILABLE = u'Сервис недоступен'

    RESET_AVAILABLE_STATUSES = [
        DSS.PRIV_CONFIRMATING,
        DSS.REGISTERED,
        DSS.WANT_CHANGE_DOU
    ]

    RESPONSES = {
        DSS.ACCEPTED: ALREADY_ENROLLED,
        DSS.ARCHIVE: SUCCESS,
        DSS.DIDNT_COME: SUCCESS,
        DSS.DIRECTED: ALREADY_DIRECTED,
        DSS.DUL_CONFIRMATING: SUCCESS,
        DSS.MED_CONFIRMATING: SUCCESS,
        DSS.PRIV_CONFIRMATING: SUCCESS,
        DSS.REFUSED: SUCCESS,
        DSS.REGISTERED: SUCCESS,
        DSS.TUTOR_CONFIRMATING: SUCCESS,
        DSS.WANT_CHANGE_DOU: SUCCESS,
        DSS.ZAGS_CHECKING: SERVICE_IS_NOT_AVAILABLE
    }


# Последовательность полей на форме соответствует последовательности в кортеже
# ((<fieldset>, (<fieldset_description>, (<field>, ...))), ...)
# ((<field>, <field_description>), ...)
ATTRIBUTES_FIELDS_MAP = (
    ('birthplace', (u"Место рождения", (
        'country',
        'region',
        'city'
    ))),
    ('personal_number', u"Личный номер"),
    ('force_kind', u"Принадлежность к виду или роду войск"),
    ('military_unit', u"Воинская часть (Подразделение)"),
    ('dismissal_date', u"Дата увольнения"),
    ('rank', u"Звание")
)

PRIVILEGE_CONFIRMATION_STATUSES_MAP = {
    True: u"Подтверждена",
    False: u"Не подтверждена"
}

# Шаблон сообщения о постановки детей в очередь
CHILDREN_APPLY_IN_QUEUE_TMP = (
    u"Ваш ребенок поставлен на учет. Регистрационный номер ({client_id})")


class DepartmentAttribute(BaseEnumerate):
    @classmethod
    def generate(cls):
        # Формируем Enum динамически
        for field, description in ATTRIBUTES_FIELDS_MAP:
            if isinstance(description, tuple):
                # Если fieldset
                description, _ = description

            setattr(cls, field.upper(), field)
            cls.values.update({field: description})

DepartmentAttribute.generate()


NOTIFICATION_MODE = {
    'WANT_CHANGE_DOU': 1,
    'IN_QUEUE': 2,
    'REJECT': 3
}


class ReturnReasonEnum(BaseEnumerate):
    SHORT_STAY_GROUP = 0
    NOT_STATED_DOU = 1
    CHANGE_DATE = 2
    values = {
        SHORT_STAY_GROUP: u'Предоставлением ранее места в'
                          u' группе кратковременного пребывания детей',
        NOT_STATED_DOU: u'Предоставлением ранее места в незаявленной ОО',
        CHANGE_DATE: u'Изменения срока  предоставления места в ОО'
    }
